@@ -475,7 +475,7 @@ class DescribeMaintenanceWindowSchedulePaginator(Boto3Paginator):
     def paginate(
         self,
         WindowId: str = None,
-        Targets: List[TargetTypeDef] = None,
+        Targets: List["TargetTypeDef"] = None,
         ResourceType: Literal["INSTANCE", "RESOURCE_GROUP"] = None,
         Filters: List[PatchOrchestratorFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
@@ -539,7 +539,7 @@ class DescribeMaintenanceWindowsForTargetPaginator(Boto3Paginator):
 
     def paginate(
         self,
-        Targets: List[TargetTypeDef],
+        Targets: List["TargetTypeDef"],
         ResourceType: Literal["INSTANCE", "RESOURCE_GROUP"],
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeMaintenanceWindowsForTargetResultTypeDef]:
@@ -617,8 +617,8 @@ class GetInventoryPaginator(Boto3Paginator):
 
     def paginate(
         self,
-        Filters: List[InventoryFilterTypeDef] = None,
-        Aggregators: List[InventoryAggregatorTypeDef] = None,
+        Filters: List["InventoryFilterTypeDef"] = None,
+        Aggregators: List["InventoryAggregatorTypeDef"] = None,
         ResultAttributes: List[ResultAttributeTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetInventoryResultTypeDef]:
